@@ -102,7 +102,7 @@ class TestRun(unittest.TestCase):
             os.path.dirname(__file__),
             "this_is_a_path_that_doesnt_exist_yes_it_goes_on_and_on_my_friend",
         )
-        with self.assertRaises(Exception):
+        with self.assertRaises(FileNotFoundError):
             runner.run(tests=[path])
 
     def test_unittest_TestResult(self):
@@ -148,8 +148,9 @@ class TestRunOutput(unittest.TestCase):
 
         if re.search(globbed, got, re.DOTALL) is None:
             self.fail(
-                "\n    " +
-                "\n    ".join(ndiff(got.splitlines(), dedented.splitlines()))
+                "\n    " + "\n    ".join(
+                    ndiff(got.splitlines(), dedented.splitlines()),
+                ),
             )
 
     def test_unsuccessful_run(self):
@@ -198,7 +199,7 @@ class TestRunOutput(unittest.TestCase):
             Ran 5 tests in 0.000s
 
             FAILED (successes=3, failures=2)
-            """  # noqa: E501
+            """,  # noqa: E501
         )
 
     def test_single_test(self):
@@ -213,7 +214,7 @@ class TestRunOutput(unittest.TestCase):
             Ran 1 test in 0.000s
 
             PASSED (successes=1)
-            """
+            """,
         )
 
     def test_empty_run(self):
@@ -225,7 +226,25 @@ class TestRunOutput(unittest.TestCase):
             Ran 0 tests in 0.000s
 
             PASSED
-            """
+            """,
+        )
+
+    def test_expected_failure(self):
+        self.assertOutputIs(
+            tests=["virtue.tests.samples.one_expected_failure"],
+            expected="""
+            virtue.tests.samples.one_expected_failure
+              Foo
+                test_foo ...                 [XFAIL]
+
+            ========================================
+            [XFAIL]
+            virtue.tests.samples.one_expected_failure.Foo.test_foo
+            ----------------------------------------
+            Ran 1 test in 0.000s
+
+            PASSED (expected_failures=1)
+            """,
         )
 
     def test_unexpected_success(self):
@@ -251,7 +270,7 @@ class TestRunOutput(unittest.TestCase):
             Traceback (most recent call last):
               File "•unittest/case.py•", line •, in •
                 •
-              File "•virtue/tests/samples/failures_and_unexpected_passes.py•", line •, in test_foo
+              File "•/failures_and_unexpected_passes.py•", line •, in test_foo
                 self.fail("Nope!")
               File "•unittest/case.py•", line •, in fail
                 raise self.failureException(msg)
@@ -265,5 +284,5 @@ class TestRunOutput(unittest.TestCase):
             Ran 5 tests in 0.000s
 
             FAILED (successes=1, failures=1, unexpected_successes=3)
-            """
+            """,
         )
